PythonSetFilterer
=================

.. currentmodule:: pykeen.sampling.filtering

.. autoclass:: PythonSetFilterer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PythonSetFilterer.contains

   .. rubric:: Methods Documentation

   .. automethod:: contains
